@@ -374,3 +374,33 @@ calls_combine_by <- function(operator, calls) {
     f = function(x, y) call(operator, x, y)
   )
 }
+
+#' Check if a call or list of calls uses the pipe operator (%>%)
+#'
+#' Recursively searches through a call or list of calls to determine
+#' if the pipe operator `%>%` is used anywhere.
+#'
+#' @param x (`call`, `name`, or `list` of calls) The call(s) to check.
+#'
+#' @return `logical(1)` `TRUE` if `%>%` is found, `FALSE` otherwise.
+#'
+#' @keywords internal
+#'
+call_uses_magrittr_pipe <- function(x) {
+  if (is.call(x)) {
+    # Check if there is the pipe operator
+    # Handle both quote(`%>%`) and as.name("%>%") cases
+    return(any(grepl("%>%", x, fixed = TRUE)))
+  }
+
+  if (is.list(x) && length(x)) {
+    # Check all elements in the list
+    for (call_x in x) {
+      if (Recall(call_x)) {
+        return(TRUE)
+      }
+    }
+  }
+
+  FALSE
+}
